@@ -1,12 +1,15 @@
+__version__ = '0.0.4'
+
 import colorsys
 import random
+import string
 
 RGBInt = tuple[int, int, int]
 RGBFloat = tuple[float, float, float]
 HexColor = int
 
 
-def minmax_scaler(value, oldmin, oldmax, newmin=0.0, newmax=1.0) -> float:
+def minmax_scaler(value: float, oldmin: float, oldmax: float, newmin: float = 0.0, newmax: float = 1.0) -> float:
     '''
     >>> minmax_scaler(50, 0, 100, 0.0, 1.0)
     0.5
@@ -47,6 +50,10 @@ def random_rgba():
     return random.randrange(255), random.randrange(255), random.randrange(255), 255
 
 
+def random_hex():
+    return f"#{int.from_bytes(random.randbytes(3), 'little'):06x}"
+
+
 def css_hex(color: int) -> str:
     return f'#{color:06X}'
 
@@ -67,7 +74,7 @@ def to_rgb_float(color: RGBInt) -> RGBFloat:
     )
 
 
-def hls_to_css_hex(h, l, s) -> str:
+def hls_to_css_hex(h: float, l: float, s: float) -> str:
     r, g, b = colorsys.hls_to_rgb(h, l, s)
     r = int(minmax_scaler(r, 0, 1, 0, 255))
     g = int(minmax_scaler(g, 0, 1, 0, 255))
@@ -111,3 +118,7 @@ def font_border_colors(
     h, l, s = colorsys.rgb_to_hls(*rgb)
     border_color = color if l < border_threshold else hls_to_css_hex(h, l * 0.7, s)
     return font_color(color), border_color
+
+
+def is_hex_color(v: str) -> bool:
+    return v.startswith('#') and set(v[1:]) <= set(string.hexdigits)
